@@ -35,18 +35,14 @@ def __getattr__(name):
     for each_mod in search_mods:
         if hasattr(each_mod, name):
             mod_name = search_strs[search_mods.index(each_mod)]
-            dup_dict.update(
-                {
-                    name: getattr(each_mod, name),
-                    mod_name: each_mod
-                    }
-                )
+            dup_dict.update({
+                name: getattr(each_mod, name),
+                mod_name: each_mod
+            })
     if len(dup_dict) > 2:
         dup_dict.pop(name)
-        raise AttributeError(
-            f"The attribute {name} is duplicated in "
-            f"{', '.join(dup_dict.keys())}"
-            )
+        raise AttributeError(f"The attribute {name} is duplicated in "
+                             f"{', '.join(dup_dict.keys())}")
     if len(dup_dict) < 2:
         raise AttributeError(f"The attribute {name} is not found")
 
@@ -84,52 +80,46 @@ class NameFilter(logging.Filter):
         fixed_text = record.msg
         curr_bold = ""
         curr_faint = ""
-        style_tag = {"f": "cr.Fore", "s": "cr.Style", "b": "back"}
+        style_tag = {"f": "fore", "s": "style", "b": "back"}
         each_attrib_count = 0
         for style_search in style_tag:
             style_regex = r"%" + style_search + \
-                          r"\.(\w*)%(.*?)%" + style_search + r"%"
+                r"\.(\w*)%(.*?)%" + style_search + r"%"
             add_attrib = re.findall(style_regex, record.msg)
             if add_attrib:
                 for each_specific_attrib in add_attrib:
                     attrib_add = each_specific_attrib[0]
                     if attrib_add.upper(
-                            ) not in valid_attrib[each_attrib_count]:
+                    ) not in valid_attrib[each_attrib_count]:
                         print(f"Invalid option specified - {attrib_add}")
                         continue
                     fixed_text = re.sub(
                         style_regex,
-                        text_color(
-                            each_specific_attrib[1], attrib_add,
-                            style_tag[style_search]
-                            ),
+                        text_color(each_specific_attrib[1], attrib_add,
+                                   style_tag[style_search]),
                         fixed_text,
                         count=1,
-                        )
+                    )
             each_attrib_count += 1
             if style_search == "s":
                 curr_bold = error_color_format.get(
-                    record.levelname.lower()
-                    ).get("bright", "")
+                    record.levelname.lower()).get("bright", "")
                 if curr_bold:
                     curr_bold = cr.Style.BRIGHT
                 curr_faint = error_color_format.get(
-                    record.levelname.lower()
-                    ).get("faint", "")
+                    record.levelname.lower()).get("faint", "")
                 if curr_faint:
                     curr_faint = cr.Style.DIM
 
         curr_color = error_color_format.get(record.levelname.lower()).get(
-            "color", ""
-            )
+            "color", "")
         if curr_color.isnumeric():
             curr_color = "\033[" + curr_color + "m"
         else:
             curr_color = getattr(cr.Fore, curr_color.upper(), "")
 
         curr_back = error_color_format.get(record.levelname.lower()).get(
-            "background", ""
-            )
+            "background", "")
         if curr_back.isnumeric():
             curr_back = "\033[" + curr_back
         else:
@@ -138,10 +128,8 @@ class NameFilter(logging.Filter):
         curr_reset = curr_back + curr_color + curr_faint + curr_bold
         reset_text = curr_reset + fixed_text.replace(cr.Fore.RESET, curr_color)
         reset_text = reset_text.replace(cr.Back.RESET, curr_back)
-        reset_text = reset_text.replace(
-            cr.Style.RESET_ALL,
-            curr_faint + curr_bold
-            )
+        reset_text = reset_text.replace(cr.Style.RESET_ALL,
+                                        curr_faint + curr_bold)
         record.msg = reset_text + curr_reset
         return True
 
@@ -186,35 +174,31 @@ caller_log_format = (r"%(asctime)s.%(msecs)03d %(name)-20s %(caller)-60s  "
                      r"%(levelname)-10s "
                      r"%(message)-s")
 caller_color_format = cl.DEFAULT_FIELD_STYLES
-caller_color_format.update(
-    {
-        "caller": {
-            "color": 133
-            },
-        "varname": {
-            "color": "red"
-            },
-        "levelname": {
-            "color": 48
-            },
-        }
-    )
+caller_color_format.update({
+    "caller": {
+        "color": 133
+    },
+    "varname": {
+        "color": "red"
+    },
+    "levelname": {
+        "color": 48
+    },
+})
 
 error_color_format = cl.DEFAULT_LEVEL_STYLES
-error_color_format.update(
-    {
-        "error": {
-            "color": "black",
-            "background": "red"
-            },
-        "info": {
-            "color": "blue"
-            },
-        "warning": {
-            "color": "red"
-            },
-        }
-    )
+error_color_format.update({
+    "error": {
+        "color": "black",
+        "background": "red"
+    },
+    "info": {
+        "color": "blue"
+    },
+    "warning": {
+        "color": "red"
+    },
+})
 
 default_log_path = ""
 default_level = "INFO"
@@ -227,46 +211,37 @@ try:
     default_log_path = settings.logging_path
 except AttributeError:
     base_log.critical(
-        f"'logging_path' missing in settings using {default_log_path}"
-        )
+        f"'logging_path' missing in settings using {default_log_path}")
 
 try:
     default_level = settings.logging_level
 except AttributeError:
     base_log.critical(
-        f"'logging_level' missing in settings using {default_level}"
-        )
+        f"'logging_level' missing in settings using {default_level}")
 
 try:
     default_file_level = settings.logging_file_level
 except AttributeError:
     base_log.critical(
-        f"'logging_log_level' missing in settings using {default_file_level}"
-        )
+        f"'logging_log_level' missing in settings using {default_file_level}")
 
 try:
     default_auto_create = settings.logging_auto_create_dir
 except AttributeError:
-    base_log.critical(
-        f"'logging_auto_create_dir' missing in settings using "
-        f"{default_auto_create}"
-        )
+    base_log.critical(f"'logging_auto_create_dir' missing in settings using "
+                      f"{default_auto_create}")
 
 try:
     default_log_to_file = settings.logging_log_to_file
 except AttributeError:
-    base_log.critical(
-        f"'logging_log_to_file' missing in settings using "
-        f"{default_log_to_file}"
-        )
+    base_log.critical(f"'logging_log_to_file' missing in settings using "
+                      f"{default_log_to_file}")
 
 try:
     default_log_ext = settings.logging_ext
 except AttributeError:
-    base_log.critical(
-        f"'logging_ext' missing in settings using "
-        f"{default_log_ext}"
-        )
+    base_log.critical(f"'logging_ext' missing in settings using "
+                      f"{default_log_ext}")
 
 cl.install(logger=base_log)
 log_path = os.path.normpath(default_log_path)
@@ -291,10 +266,8 @@ level_numbers.sort()
 debug_levels = "|".join(level_list)
 
 
-def set_log_path(
-    path: str = log_path,
-    auto_create: bool = default_auto_create
-        ) -> str:
+def set_log_path(path: str = log_path,
+                 auto_create: bool = default_auto_create) -> str:
     """Set log path
 
     Set globally at load with config, can be called to modify path per module
@@ -314,7 +287,7 @@ def set_log_path(
                 limit=3,
                 default="yes",
                 blank=True,
-                )
+            )
         if not create_path or create_path == "yes":
             try:
                 os.makedirs(path)
@@ -357,10 +330,8 @@ def verify_level(level: [str, int]) -> bool:
         exit_string = (f"ERROR - Invalid debug level\n"
                        f"You entered %c.cyan%{level}%c%\n"
                        f"Acceptable levels are:\n{level_numbers_string}")
-        level_dym = difflib.get_close_matches(
-            level,
-            level_numbers_string.split(", ")
-            )
+        level_dym = difflib.get_close_matches(level,
+                                              level_numbers_string.split(", "))
         if level_dym:
             exit_string += f"\nDid you mean: %c.cyan%{level_dym[0]}%c%?"
         base_log.warning(exit_string)
@@ -404,7 +375,7 @@ def clear_logs(force: bool = False):
             f"Default is no:\n",
             default="no",
             blank=True,
-            )
+        )
 
     if del_files == "yes":
         shutil.rmtree(log_path, onerror=err_handler)
@@ -432,7 +403,7 @@ def get_parent_logger() -> [None, logging.Logger]:
 class Timer:
     """Custom timer class
 
-       Level sets what level of debug the timer displays at
+    Level sets what level of debug the timer displays at
     """
 
     _counter = 0
@@ -474,7 +445,7 @@ class Timer:
             level=self.logger.root.level,
             fmt=caller_log_format,
             field_styles=caller_color_format,
-            )
+        )
 
     def start_timer(self, note: str = "", show_process: bool = False):
         """Start timer
@@ -514,10 +485,8 @@ class Timer:
         fcaller = f"{self.caller}.{self.function}.{local_func}.{self.vid}"
         setattr(Timer, "scaller", fcaller)
         if not self.start_time:
-            self.logger.log(
-                logging.getLevelName(self.level),
-                "Timer was not started"
-                )
+            self.logger.log(logging.getLevelName(self.level),
+                            "Timer was not started")
             setattr(Timer, "svid", "")
             setattr(Timer, "scaller", "")
             return 0
@@ -527,14 +496,12 @@ class Timer:
 
         if not note:
             if show_process:
-                logger_note = f"Timer took {total_time:.3f} seconds - " \
-                              f"{self.vid}"
+                logger_note = f"Timer took {total_time:.3f} seconds - " f"{self.vid}"
             else:
                 logger_note = f"Timer took {total_time:.3f} seconds"
         else:
             logger_note = note.replace("%t%", f"{total_time:.3f}").replace(
-                "%p%", self.vid
-                )
+                "%p%", self.vid)
 
         self.timer_logger.log(logging.getLevelName(self.level), logger_note)
         setattr(Timer, "svid", "")
@@ -561,10 +528,7 @@ def text_color(text: str, style: str, attrib: str) -> str:
     elif attrib.lower() == "style":
         reset = cr.Style.RESET_ALL
 
-    return getattr(
-        getattr(cr, attrib.title()),
-        style.upper()
-        ) + text + reset
+    return getattr(getattr(cr, attrib.title()), style.upper()) + text + reset
 
 
 class CallerFilter(logging.Filter):
@@ -603,7 +567,7 @@ def get_logger(
     level: [str, int] = default_level,
     log_to_file: bool = default_log_to_file,
     log_file_level: [str, int] = default_file_level,
-        ) -> logging.Logger:
+) -> logging.Logger:
     """Configures a logger
 
     :param caller_name: Name of module or custom name
@@ -634,10 +598,8 @@ def get_logger(
     log_file_name = f"{caller_name}-{log_time}.{default_log_ext}"
     log_full_path = os.path.join(log_path, log_file_name)
 
-    log_formatter = logging.Formatter(
-        fmt=file_log_format,
-        datefmt="%Y-%m-%d %H:%M:%S"
-        )
+    log_formatter = logging.Formatter(fmt=file_log_format,
+                                      datefmt="%Y-%m-%d %H:%M:%S")
 
     logger = logging.getLogger(caller_name)
     logger.setLevel(level)
@@ -672,7 +634,7 @@ def set_config(
     display_spacer: str = spacer,
     display_spacer_color: str = spacer_color,
     specific_logger_levels: dict = settings.specific_loggers,
-        ):
+):
     """
     Sets default config
 
@@ -723,7 +685,7 @@ def set_config(
         "spacer": display_spacer,
         "spacer_color": display_spacer_color,
         "specific_loggers": specific_logger_levels,
-        }
+    }
 
     write_config(settings_write)
 
@@ -744,10 +706,8 @@ def set_config(
             try:
                 logging.getLogger(lkey).setLevel(specific_loggers.get(lkey))
             except ValueError:
-                logging.warning(
-                    f"Cannot set {key} to "
-                    f"{specific_loggers.get(key)}"
-                    )
+                logging.warning(f"Cannot set {key} to "
+                                f"{specific_loggers.get(key)}")
 
 
 cr.init(autoreset=True)
@@ -768,7 +728,7 @@ if not name_filter_added:
         logger=base_logger,
         fmt=caller_log_format,
         field_styles=caller_color_format,
-        )
+    )
 
 filter_added = False
 for format_filters in base_logger.filters:
@@ -781,7 +741,7 @@ if not filter_added:
         logger=base_logger,
         fmt=caller_log_format,
         field_styles=caller_color_format,
-        )
+    )
 
 # Specific loggers
 try:
